=====================
django-public-project
=====================

Django Public Project (DPP) is a content management system tailored to represent and expose the various
structural parts and participants in big projects and picture the inderdependencies between them.

DPP can be used by civic transparency groups or governmental institutions to monitor or inform about 
big publicly funded projects for
helping the public to easier follow the progress of the project and get a deeper understanding of what
is going on, who is acting/involved and how the project goals changed over time. 

DPP is not self-installable but comes as a Django app, so it needs some development work to be integrated
inside a Django project. Nevertheless it comes with a predefined site layout tailored to the domain described
above and a Django admin integration to enter all the data about project parts, participants and events occured,
so after a quick initial installation and deployment it can be used and updated by non-technical folks.

Current languages available: EN | DE


Documentation
=============
Read more about DPP in the ReadTheDocs documentation:

* http://django-public-project.readthedocs.org/
